/*
 * author: bto
 * date: 19 jun 2020
 * blink program for __AVR_AT90S2313__ on an olimex AVR P20 dev board
 */

#include "olimex_avr-p20.h"
#include "avr/interrupt.h"
#include "lcd_driver.h"
#include "uart.h"

ISR(INT0_vect) 
{
    TOGGLE_LED0;
    _delay_ms(10); // debounce
}

void 
blink(void)
{
    TOGGLE_LED0;
    _delay_ms(1000);
}

int 
setup(void)
{
    INIT_LED0;
    LED0_OFF; // led off
    
    INIT_BUT0;

    // interrupts 
    setbit(SREG,SREG_I); // enable global intrrupts
    setbit(GIMSK,INT0);  // enable INT0
    
    // interrupt on falling edge (button push)
    setbit(MCUCR,ISC01);
    setbit(MCUCR,ISC00);

    // setup uart
    //setup_uart();

    // initialize lcd
    DDRB |= 0x0F; // set output pins for LCD
    LCD_BUS = 0x01; 
    
    DDRD  = 0x70; // 0b01110000 set output pins for LCD RS, RW, E
    LCD_REG = 0x00; 
    
    setup_lcd();
    lcd_goto(3,1);
    lcd_puts("hello, world!");
    lcd_goto(2,2);
    lcd_puts("hello, world!");
    lcd_goto(1,3);
    lcd_puts("hello, world!");
    lcd_goto(0,4);
    lcd_puts("hello, world!");

    return SUCCESS;
}

int 
main(void)
{
    setup();
    while(TRUE) {
        blink();
    }
    return SUCCESS;
}
